@@ -1,16 +1,43 @@
+\\xNotesOn
+\\xNotesOff
+\\xNote
+\\wordwrap-string-internal
+\\wordwrap-string
+\\wordwrap-lines
+\\wordwrap-internal
+\\wordwrap-field
+\\wordwrap
 \\withMusicProperty
+\\with-url
+\\with-link
+\\with-dimensions
+\\with-color
 \\with
+\\whiteout
 \\whiteTriangleMarkup
+\\walkerHeadsMinor
+\\walkerHeads
+\\vspace
+\\void
+\\voiceTwoStyle
 \\voiceTwo
+\\voiceThreeStyle
 \\voiceThree
+\\voiceOneStyle
 \\voiceOne
+\\voiceNeutralStyle
+\\voiceFourStyle
 \\voiceFour
+\\vocalName
 \\virgula
 \\virga
 \\verylongfermata
 \\versus
 \\version
+\\verbatim-file
+\\vcenter
 \\varcoda
+\\upright
 \\upprall
 \\upmordent
 \\upbow
@@ -18,8 +45,10 @@
 \\unset
 \\unit
 \\unfoldRepeats
+\\underline
 \\unaCorda
 \\unHideNotes
+\\typewriter
 \\type
 \\tweak
 \\turn
@@ -27,114 +56,201 @@
 \\tupletNeutral
 \\tupletDown
 \\trill
+\\triangle
 \\treCorde
 \\transposition
 \\transposedCueDuring
 \\transpose
+\\transparent
+\\translate-scaled
+\\translate
+\\topLevelAlignment
+\\tocTitleMarkup
+\\tocItemWithDotsMarkup
+\\tocItemMarkup
+\\tocItem
 \\tiny
+\\timing
 \\times
+\\timeSignatureSettings
+\\timeSignatureFraction
 \\time
 \\tildeSymbol
+\\tied-lyric
+\\tieWaitForNote
 \\tieUp
 \\tieSolid
 \\tieNeutral
+\\tieHalfSolid
+\\tieHalfDashed
 \\tieDown
 \\tieDotted
 \\tieDashed
+\\tieDashPattern
 \\thumb
 \\textSpannerUp
 \\textSpannerNeutral
 \\textSpannerDown
+\\textLengthOn
+\\textLengthOff
+\\text
 \\tenuto
+\\tempoWholesPerMinute
 \\tempo
+\\teeny
 \\tag
-\\sustainUp
-\\sustainDown
+\\table-of-contents
+\\tablatureFormat
+\\tabStaffLineLayoutFunction
+\\tabFullNotation
+\\systemStartDelimiter
+\\sustainOn
+\\sustainOff
+\\super
+\\subdivideBeams
+\\sub
+\\styledNoteHeads
+\\strut
 \\stropha
+\\strokeFingerOrientations
+\\stringTunings
+\\stringOneTopmost
+\\stringNumberOrientations
 \\stopped
 \\stopTrillSpan
 \\stopTextSpan
 \\stopStaff
+\\stopSlashedGraceMusic
 \\stopGroup
+\\stopGraceSlur
 \\stopGraceMusic
 \\stopAppoggiaturaMusic
 \\stopAcciaccaturaMusic
 \\stop
+\\stencil
 \\stemUp
 \\stemNeutral
 \\stemDown
 \\startTrillSpan
 \\startTextSpan
 \\startStaff
+\\startSlashedGraceMusic
+\\startRepeatType
 \\startGroup
+\\startGraceSlur
 \\startGraceMusic
 \\startAppoggiaturaMusic
 \\startAcciaccaturaMusic
 \\start
 \\staccato
 \\staccatissimo
+\\squashedPosition
 \\spp
 \\spacingTweaks
 \\sp
-\\sostenutoUp
-\\sostenutoDown
+\\southernHarmonyHeadsMinor
+\\southernHarmonyHeads
+\\sostenutoOn
+\\sostenutoOff
+\\soloText
+\\soloIIText
+\\snappizzicato
 \\smaller
+\\smallCaps
 \\small
 \\slurUp
 \\slurSolid
 \\slurNeutral
+\\slurHalfSolid
+\\slurHalfDashed
 \\slurDown
 \\slurDotted
 \\slurDashed
+\\slurDashPattern
+\\slashedGrace
+\\slashed-digit
+\\slashChordSeparator
 \\skipTypesetting
 \\skip
 \\simultaneous
+\\simple
 \\signumcongruentiae
 \\showStaffSwitch
+\\showSplitTiedTabNotes
 \\shortfermata
+\\shortVocalName
+\\shortInstrumentName
 \\shiftOnnn
 \\shiftOnn
 \\shiftOn
 \\shiftOff
 \\shiftDurations
+\\sharp
+\\shape
 \\sfz
 \\sfp
 \\sff
 \\sf
-\\setTextDim
-\\setTextDecresc
-\\setTextCresc
-\\setHairpinDim
-\\setHairpinDecresc
-\\setHairpinCresc
-\\setEasyHeads
+\\settingsFrom
 \\setDefaultDurationToQuarter
 \\set
+\\sesquisharp
+\\sesquiflat
 \\sequential
+\\semisharp
+\\semiflat
 \\semicirculus
 \\semiGermanChords
 \\segno
-\\scoreTweak
+\\searchForVoice
+\\scriptDefinitions
 \\score
+\\scaleDurations
+\\scale
+\\sans
+\\sacredHarpHeadsMinor
 \\sacredHarpHeads
 \\rtoe
+\\rounded-box
+\\rotate
+\\roman
 \\rightHandFinger
+\\right-column
+\\right-brace
+\\right-align
 \\right
 \\rheel
 \\rfz
+\\revertTimeSignatureSettings
 \\revert
 \\reverseturn
+\\retrograde
+\\restrainOpenStrings
 \\rest
 \\responsum
 \\resetRelativeOctave
+\\replace
 \\repeatTie
+\\repeatCountVisibility
 \\repeat
 \\removeWithTag
 \\remove
 \\relative
+\\rehearsalMark
+\\raise
+\\quotedEventTypes
+\\quotedCueEventTypes
 \\quoteDuring
 \\quilisma
+\\put-adjacent
+\\pushToTag
 \\pt
+\\property-recursive
+\\printPartCombineTexts
+\\printKeyCancellation
+\\predefinedFretboardsOn
+\\predefinedFretboardsOff
+\\predefinedDiagramTable
 \\prallup
 \\prallprall
 \\prallmordent
@@ -144,143 +260,313 @@
 \\pppp
 \\ppp
 \\pp
+\\powerChords
+\\powerChordSymbol
+\\powerChordExceptions
+\\postscript
 \\portato
+\\pointAndClickTypes
+\\pointAndClickOn
+\\pointAndClickOff
 \\pitchedTrill
 \\pipeSymbol
 \\phrygian
 \\phrasingSlurUp
+\\phrasingSlurSolid
 \\phrasingSlurNeutral
+\\phrasingSlurHalfSolid
+\\phrasingSlurHalfDashed
 \\phrasingSlurDown
+\\phrasingSlurDotted
+\\phrasingSlurDashed
+\\phrasingSlurDashPattern
 \\pes
+\\pedalUnaCordaStyle
+\\pedalUnaCordaStrings
+\\pedalSustainStyle
+\\pedalSustainStrings
+\\pedalSostenutoStyle
+\\pedalSostenutoStrings
+\\pattern
+\\path
 \\partialJazzMusic
 \\partialJazzExceptions
 \\partial
+\\partcombineUp
+\\partcombineUnisonoOnce
+\\partcombineUnisono
+\\partcombineSoloIOnce
+\\partcombineSoloIIOnce
+\\partcombineSoloII
+\\partcombineSoloI
+\\partcombineForce
+\\partcombineDown
+\\partcombineChordsOnce
+\\partcombineChords
+\\partcombineAutomaticOnce
+\\partcombineAutomatic
+\\partcombineApartOnce
+\\partcombineApart
 \\partcombine
+\\partCombineTextsOnNote
 \\partCombineListener
 \\parenthesize
 \\parenthesisOpenSymbol
 \\parenthesisCloseSymbol
 \\parallelMusic
 \\paper
+\\palmMuteOn
+\\palmMuteOff
+\\palmMute
 \\pageTurn
 \\pageBreak
+\\page-ref
+\\page-link
+\\pad-x
+\\pad-to-box
+\\pad-markup
+\\pad-around
 \\p
+\\overrideTimeSignatureSettings
 \\overrideProperty
+\\override-lines
 \\override
+\\ottava
 \\oriscus
 \\open
 \\oneVoice
 \\once
-\\oldaddlyrics
-\\octave
-\\objectid
+\\on-the-fly
+\\octaveCheck
+\\numericTimeSignature
+\\number
+\\null
 \\notemode
+\\noteToFretFunction
+\\note-by-number
+\\note
 \\normalsize
+\\normal-text
+\\normal-size-super
+\\normal-size-sub
 \\noPageTurn
 \\noPageBreak
+\\noChordSymbol
 \\noBreak
 \\noBeam
 \\newSpacingSection
 \\new
 \\neumeDemoLayout
+\\natural
 \\name
+\\musicglyph
 \\musicMap
 \\mp
 \\mordent
+\\modalTranspose
+\\modalInversion
 \\mm
 \\mixolydian
+\\minorChordModifier
 \\minor
+\\midiInstrument
+\\midiChannelMapping
 \\midi
+\\middleCPosition
+\\middleCClefPosition
 \\mf
+\\metronomeMarkFormatter
+\\mergeDifferentlyHeadedOn
+\\mergeDifferentlyHeadedOff
+\\mergeDifferentlyDottedOn
+\\mergeDifferentlyDottedOff
 \\melismaEnd
+\\melismaBusyProperties
 \\melisma
+\\medium
+\\measureLength
 \\maxima
+\\markuplist
 \\markup
+\\markletter
+\\markalphabet
+\\markFormatter
 \\mark
 \\marcato
 \\makeClusters
+\\majorSevenSymbol
 \\major
 \\maininput
+\\magnify
 \\lyricsto
 \\lyrics
 \\lyricmode
+\\lyricMelismaAlignment
 \\lydian
 \\ltoe
+\\lower
+\\lookup
 \\longfermata
 \\longa
 \\locrian
+\\localKeySignature
 \\lineprall
 \\linea
+\\line
 \\ligature
 \\lheel
+\\left-column
+\\left-brace
+\\left-align
 \\left
 \\layout
+\\larger
+\\large
+\\languageSaveAndChange
+\\languageRestore
+\\language
 \\laissezVibrer
+\\label
 \\killCues
+\\keyAlterationOrder
 \\key
 \\keepWithTag
+\\keepAliveInterfaces
+\\justify-string
+\\justify-field
+\\justify
+\\justified-lines
+\\italic
 \\italianChords
 \\ionian
+\\inversion
+\\interscoreline
+\\instrumentTransposition
 \\instrumentSwitch
-\\includePageLayoutFile
+\\instrumentName
+\\instrumentEqualizer
+\\indent
 \\include
 \\inclinatum
+\\inStaffSegno
 \\in
 \\improvisationOn
 \\improvisationOff
+\\implicitTimeSignatureVisibility
 \\ij
 \\iij
+\\ignoreFiguredBassRest
 \\ignoreBarChecks
 \\ignatzekExceptions
 \\ignatzekExceptionMusic
 \\ictus
+\\huge
+\\hspace
+\\highStringOne
 \\hideStaffSwitch
+\\hideSplitTiedTabNotes
 \\hideNotes
 \\header
+\\hcenter-in
+\\hbracket
+\\harp-pedal
+\\harmonicsOn
+\\harmonicsOff
+\\harmonicNote
+\\harmonicByRatio
+\\harmonicByFret
+\\harmonicAccidentals
 \\harmonic
+\\handleNegativeFrets
+\\halign
+\\halfopen
 \\grobdescriptions
+\\graceSettings
 \\grace
 \\glissando
 \\germanChords
+\\general-align
 \\fz
+\\funkHeadsMinor
+\\funkHeads
 \\fullJazzExceptions
+\\fromproperty
+\\fret-diagram-verbose
+\\fret-diagram-terse
+\\fret-diagram
 \\frenchChords
+\\fraction
 \\fp
+\\footnote
+\\fontsize
+\\fontSize
+\\fontCaps
 \\flexa
+\\flat
 \\flageolet
+\\firstClef
+\\fingeringOrientations
+\\finger
 \\finalis
+\\filled-box
+\\fill-with-pattern
+\\fill-line
 \\figures
 \\figuremode
+\\figuredBassFormatter
+\\fffff
 \\ffff
 \\fff
 \\ff
 \\fermataMarkup
 \\fermata
 \\featherDurations
-\\fatText
+\\f
+\\eyeglasses
+\\extraNatural
+\\explicitKeySignatureVisibility
+\\explicitCueClefVisibility
+\\explicitClefVisibility
+\\expandFullBarRests
+\\eventChords
 \\espressivo
 \\escapedSmallerSymbol
 \\escapedParenthesisOpenSymbol
 \\escapedParenthesisCloseSymbol
 \\escapedExclamationSymbol
 \\escapedBiggerSymbol
+\\epsfile
 \\episemInitium
 \\episemFinis
 \\endincipit
 \\enddim
+\\enddecresc
 \\enddecr
 \\endcresc
 \\endcr
-\\emptyText
+\\endSpanners
+\\endRepeatType
+\\easyHeadsOn
+\\easyHeadsOff
 \\dynamicUp
 \\dynamicNeutral
 \\dynamicDown
+\\dynamicAbsoluteVolumeFunction
+\\dynamic
 \\drums
 \\drummode
+\\drumStyleTable
+\\drumPitchTable
+\\draw-line
+\\draw-hline
+\\draw-circle
 \\downprall
 \\downmordent
 \\downbow
 \\down
+\\doublesharp
+\\doubleflat
+\\doubleRepeatType
 \\dotsUp
 \\dotsNeutral
 \\dotsDown
@@ -290,14 +576,31 @@
 \\divisioMaior
 \\displayMusic
 \\displayLilyMusic
+\\dir-column
+\\dimTextDim
+\\dimTextDecresc
+\\dimTextDecr
+\\dimHairpin
 \\dim
 \\description
 \\descendens
+\\deprecatedenddim
+\\deprecatedendcresc
+\\deprecateddim
+\\deprecatedcresc
 \\denies
 \\deminutum
 \\defaultchild
+\\defaultTimeSignature
+\\defaultNoteHeads
+\\defaultBarType
 \\default
+\\decrescendoSpanner
+\\decresc
 \\decr
+\\deadNotesOn
+\\deadNotesOff
+\\deadNote
 \\dashUnderscore
 \\dashPlus
 \\dashLarger
@@ -305,77 +608,162 @@
 \\dashDot
 \\dashDash
 \\dashBar
+\\cueDuringWithClef
 \\cueDuring
+\\cueClefUnset
+\\cueClef
+\\crossStaff
+\\crescendoSpanner
+\\crescTextCresc
+\\crescHairpin
 \\cresc
+\\createSpacing
 \\cr
 \\context
 \\consists
-\\compressMusic
+\\concat
+\\compressFullBarRests
+\\compoundMeter
+\\command-name
+\\combine
+\\column-lines
+\\column
 \\coda
 \\cm
+\\clefPosition
+\\clefOctavation
+\\clefGlyph
 \\clef
 \\circulus
+\\circle
 \\chords
 \\chordmodifiers
 \\chordmode
+\\chordRootNamer
+\\chordPrefixSpacer
+\\chordNoteNamer
+\\chordNameSeparator
+\\chordNameLowercaseMinor
+\\chordNameFunction
+\\chordNameExceptionsPartial
+\\chordNameExceptionsFull
+\\chordNameExceptions
+\\char
 \\change
+\\center-column
+\\center-align
 \\center
 \\cavum
+\\caps
 \\caesura
 \\cadenzaOn
 \\cadenzaOff
 \\breve
 \\breathe
+\\breakDynamicSpan
 \\break
 \\bracketOpenSymbol
 \\bracketCloseSymbol
+\\bracket
+\\box
+\\bookpart
+\\bookOutputSuffix
+\\bookOutputName
 \\book
+\\bold
 \\blackTriangleMarkup
 \\bigger
 \\bendAfter
+\\beatStructure
+\\beamHalfMeasure
+\\beamExceptions
+\\beam
+\\bassStaffProperties
+\\bassFigureStaffAlignmentUp
+\\bassFigureStaffAlignmentNeutral
+\\bassFigureStaffAlignmentDown
+\\bassFigureExtendersOn
+\\bassFigureExtendersOff
+\\baseMoment
+\\barNumberVisibility
+\\barNumberFormatter
 \\barNumberCheck
+\\barCheckSynchronize
+\\barAlways
 \\bar
 \\balloonText
+\\balloonLengthOn
+\\balloonLengthOff
 \\balloonGrobText
+\\backslashed-digit
+\\automaticBars
 \\autochange
+\\autoCautionaries
+\\autoBeaming
 \\autoBeamOn
 \\autoBeamOff
+\\autoBeamCheck
+\\autoAccidentals
+\\auto-footnote
 \\augmentum
 \\auctum
 \\assertBeamSlope
 \\assertBeamQuant
 \\ascendens
-\\arpeggioUp
-\\arpeggioNeutral
-\\arpeggioDown
+\\arrow-head
+\\arpeggioParenthesisDashed
+\\arpeggioParenthesis
+\\arpeggioNormal
 \\arpeggioBracket
+\\arpeggioArrowUp
+\\arpeggioArrowDown
 \\arpeggio
 \\appoggiatura
 \\applyOutput
 \\applyMusic
 \\applyContext
+\\appendToTag
 \\alternative
+\\alterBroken
 \\allowPageTurn
 \\alias
+\\aikenHeadsMinor
 \\aikenHeads
 \\afterGraceFraction
 \\afterGrace
 \\aeolian
-\\addquote
 \\addlyrics
+\\additionalPitchPrefix
+\\addQuote
 \\addInstrumentDefinition
+\\accidentalStyle
 \\acciaccatura
 \\accepts
 \\accentus
 \\accent
+\\abs-fontsize
+\\aDueText
+\\RemoveEmptyTabStaffContext
 \\RemoveEmptyStaffContext
 \\RemoveEmptyRhythmicStaffContext
+\\RemoveEmptyDrumStaffContext
 \\IJ
 \\IIJ
+\\EventClasses
+\\C
+\\B
 \\AncientRemoveEmptyStaffContext
+\\A
+spacing
+signature
+routine
+notes
+handler
+corrected
+beams
+arpeggios
 Volta_engraver
 Voice
-Vertically_spaced_contexts_engraver
 Vertical_align_engraver
 Vaticana_ligature_engraver
 VaticanaVoice
@@ -391,14 +779,12 @@ Tie_engraver
 Text_spanner_engraver
 Text_engraver
 Tempo_performer
+Tab_tie_follow_engraver
 Tab_staff_symbol_engraver
 Tab_note_heads_engraver
 TabVoice
 TabStaff
 System_start_delimiter_engraver
-Swallow_performer
-Swallow_engraver
-String_number_engraver
 Stem_engraver
 Stanza_number_engraver
 Stanza_number_align_engraver
@@ -407,14 +793,14 @@ Staff_performer
 Staff_collecting_engraver
 StaffGroup
 Staff
-Span_dynamic_performer
+Spanner_break_forbid_engraver
+Span_bar_stub_engraver
 Span_bar_engraver
 Span_arpeggio_engraver
 Spacing_engraver
 Slur_performer
 Slur_engraver
 Slash_repeat_engraver
-Skip_event_swallow_translator
 Separating_line_group_engraver
 Script_row_engraver
 Script_engraver
@@ -422,11 +808,11 @@ Script_column_engraver
 Score
 Rhythmic_column_engraver
 RhythmicStaff
-Rest_swallow_translator
 Rest_engraver
 Rest_collision_engraver
 Repeat_tie_engraver
 Repeat_acknowledge_engraver
+Pure_from_neighbor_engraver
 Pitched_trill_engraver
 Pitch_squash_engraver
 Piano_pedal_performer
@@ -434,19 +820,22 @@ Piano_pedal_engraver
 Piano_pedal_align_engraver
 PianoStaff
 Phrasing_slur_engraver
+PetrucciVoice
+PetrucciStaff
 Percent_repeat_engraver
 Part_combine_engraver
 Parenthesis_engraver
 Paper_column_engraver
 Output_property_engraver
 Ottava_spanner_engraver
-Note_swallow_translator
+Note_spacing_engraver
 Note_performer
 Note_name_engraver
 Note_heads_engraver
 Note_head_line_engraver
 NoteNames
 New_fingering_engraver
+New_dynamic_engraver
 Multi_measure_rest_engraver
 Metronome_mark_engraver
 Mensural_ligature_engraver
@@ -459,12 +848,13 @@ Lyric_engraver
 Ligature_bracket_engraver
 Ledger_line_engraver
 Laissez_vibrer_engraver
+KievanVoice
+KievanStaff
 Key_performer
 Key_engraver
+Keep_alive_together_engraver
 Instrument_switch_engraver
 Instrument_name_engraver
-InnerStaffGroup
-InnerChoirStaff
 Hyphen_engraver
 Hara_kiri_engraver
 Grob_pq_engraver
@@ -479,25 +869,31 @@ Glissando_engraver
 Fretboard_engraver
 FretBoards
 Forbid_line_break_engraver
+Footnote_engraver
 Font_size_engraver
 Fingering_engraver
 Figured_bass_position_engraver
 Figured_bass_engraver
 FiguredBass
 Extender_engraver
+Episema_engraver
+Dynamics
 Dynamic_performer
-Dynamic_engraver
+Dynamic_align_engraver
 Drum_notes_engraver
 Drum_note_performer
 DrumVoice
 DrumStaff
+Double_percent_repeat_engraver
 Dots_engraver
 Dot_column_engraver
 Devnull
 Default_bar_line_engraver
 Custos_engraver
+Cue_clef_engraver
 CueVoice
 Control_track_performer
+Concurrent_hairpin_engraver
 Collision_engraver
 Cluster_spanner_engraver
 Clef_engraver
@@ -508,23 +904,19 @@ ChordNameVoice
 ChoirStaff
 Breathing_sign_engraver
 Break_align_engraver
-Bend_after_engraver
+Bend_engraver
 Beam_performer
 Beam_engraver
+Beam_collision_engraver
 Bar_number_engraver
 Bar_engraver
 Axis_group_engraver
 Auto_beam_engraver
 Arpeggio_engraver
 Accidental_engraver
-vibraslap
-twoup
-twodown
-triangle
-threeup
-threedown
-tambourine
-splashcymbal
+solx
+soltcs
+soltcb
 solstqt
 solss
 solsqt
@@ -536,13 +928,17 @@ solk
 soldsd
 soldd
 sold
+solcs
+solcb
 solbtqt
 solbsb
 solbqt
 solbb
 solb
 sol
-snare
+six
+sitcs
+sitcb
 sistqt
 siss
 sisqt
@@ -552,21 +948,19 @@ sis
 sikk
 sik
 sidsd
-sidestick
 sidd
 sid
+sics
+sicb
 sibtqt
 sibsb
 sibqt
 sibb
 sib
 si
-shortwhistle
-shortguiro
-ridecymbalb
-ridecymbala
-ridecymbal
-ridebell
+rex
+retcs
+retcb
 restqt
 ress
 resqt
@@ -578,28 +972,17 @@ rek
 redsd
 redd
 red
+recs
+recb
 rebtqt
 rebsb
 rebqt
 rebb
 reb
 re
-pedalhihat
-opentriangle
-openloconga
-openlobongo
-openhihat
-openhiconga
-openhibongo
-opencuica
-oneup
-onedown
-mutetriangle
-muteloconga
-mutelobongo
-mutehiconga
-mutehibongo
-mutecuica
+mix
+mitcs
+mitcb
 mistqt
 miss
 misqt
@@ -611,24 +994,17 @@ mik
 midsd
 midd
 mid
+mics
+micb
 mibtqt
 mibsb
 mibqt
 mibb
 mib
 mi
-maracas
-lowtom
-lowoodblock
-lowmidtom
-lowfloortom
-lotimbale
-losidestick
-longwhistle
-longguiro
-loconga
-lobongo
-loagogo
+lax
+latcs
+latcb
 lastqt
 lass
 lasqt
@@ -640,34 +1016,25 @@ lak
 ladsd
 ladd
 lad
+lacs
+lacb
 labtqt
 labsb
 labqt
 labb
 lab
 la
-hiwoodblock
-hitimbale
 hississ
 hiss
 hisis
-hisidestick
+hisih
 his
-himidtom
-hihat
 hih
-hightom
-highfloortom
-hiconga
-hibongo
-hiagogo
 hessess
 heses
-handclap
-halfopenhihat
+heseh
 h
 gx
-guiro
 gtqs
 gtqf
 gss
@@ -702,10 +1069,6 @@ fsharp
 fs
 fqs
 fqf
-fourup
-fourdown
-fiveup
-fivedown
 fississ
 fiss
 fisis
@@ -722,6 +1085,9 @@ feses
 feseh
 fes
 feh
+fax
+fatcs
+fatcb
 fastqt
 fass
 fasqt
@@ -733,6 +1099,8 @@ fak
 fadsd
 fadd
 fad
+facs
+facb
 fabtqt
 fabsb
 fabqt
@@ -748,10 +1116,10 @@ ess
 esharpsharp
 esharp
 eses
+eseh
 es
 eqs
 eqf
-electricsnare
 eississ
 eiss
 eisis
@@ -778,6 +1146,9 @@ dsharp
 ds
 dqs
 dqf
+dox
+dotcs
+dotcb
 dostqt
 doss
 dosqt
@@ -789,6 +1160,8 @@ dok
 dodsd
 dodd
 dod
+docs
+docb
 dobtqt
 dobsb
 dobqt
@@ -819,21 +1192,14 @@ css
 csharpsharp
 csharp
 cs
-crashcymbalb
-crashcymbala
-crashcymbal
 cqs
 cqf
-cowbell
-closedhihat
-claves
 cississ
 ciss
 cisis
 cisih
 cis
 cih
-chinesecymbal
 cflatflat
 cflat
 cff
@@ -844,7 +1210,6 @@ ceses
 ceseh
 ces
 ceh
-cabasa
 c
 bx
 btqs
@@ -869,7 +1234,6 @@ beseh
 bes
 beh
 bb
-bassdrum
 b
 ax
 atqs
@@ -879,7 +1243,9 @@ ass
 asharpsharp
 asharp
 ases
+aseh
 asas
+asah
 as
 aqs
 aqf
@@ -899,8 +1265,6 @@ aeses
 aeseh
 aes
 aeh
-acousticsnare
-acousticbassdrum
 a
 \( - _ \) -
 \[ - _ \] -
@@ -917,8 +1281,8 @@ a
 \\markup - { _ } -
 \\notes - { _ } -
 \\relative - % { _ } -
-\\score - { \\n \? \\simultaneous { \\n _ \\n } \! \\n \\paper {  } \\n \? \\midi {  } \\n \! } \\n -
+\\score - { \\n \? \\simultaneous { \\n _ \\n } \! \\n \\layout {  } \\n \? \\midi {  } \\n \! } \\n -
 \\simultaneous - { _ } -
-\\sustainDown - _ \\sustainUp -
+\\sustainOn - _ \\sustainOff -
 \\times - % { _ } -
 \\transpose - % { _ } -
